# XSL Mashup

This API proxy uses an XSL policy with the document() function to
mashup XML data retrieved from multiple invocations of a remote endpoint.

The target returns a document like this :

```xml
<root>
    <procedures>
        <procedureId>1001</procedureId>
        <procedureId>1233</procedureId>
        <procedureId>3029</procedureId>
    </procedures>
</root>
```

The elaboration endpoint returns a details document for each procedure, like this:

```xml
<root>
  <procedureDetails>
    <procedureId>1001</procedureId>
    <Detail>
      <DetailType>Last change</DetailType>
      <value>2018-12-10T19:12Z</value>
    </Detail>
    <Detail>
      <DetailType>Service status</DetailType>
      <value>true</value>
    </Detail>
  </procedureDetails>
</root>
```

The XSL sheet loops through each procedure (1001, 1233, 3029) and retrieves the
detail document for that procedure. It then transforms the retrieved content,
and consolidates it all into a single XML document. Something like this:

```xml
<root>
   <procedure>
      <id>1001</id>
      <Last_change>2018-12-10T19:11Z</Last_change>
      <Service_status>true</Service_status>
   </procedure>
   <procedure>
      <id>1233</id>
      <Last_change>2018-12-08T17:18Z</Last_change>
      <Service_status>true</Service_status>
   </procedure>
   <procedure>
      <id>3029</id>
      <Last_change>2018-12-07T11:51Z</Last_change>
      <Service_status>true</Service_status>
   </procedure>
</root>
```

The mashup magic happens in [elaborate-and-mashup.xsl](./apiproxy/resources/xsl/elaborate-and-mashup.xsl). This sheet assumes the procedure details API accepts a GET at a URL formatted like
baselocation/{id} . This is codified in this statement:

```
    <xsl:variable name="location" select="concat($base_location, normalize-space(./text()))"/>
```

If the URL used to lookup the procedure IDs is of a different format, that XSL will need to be modified.
